AshNeo4j.DataLayer.Domain.Info (AshNeo4j v0.7.0)

Copy Markdown View Source

Introspection helpers for AshNeo4j.DataLayer.Domain

Summary

Functions

Label written on CREATE for all nodes whose resource belongs to this domain.

Label written on CREATE for all nodes whose resource belongs to this domain.

neo4j DSL options

Functions

neo4j_label(dsl_or_extended)

@spec neo4j_label(dsl_or_extended :: module() | map()) :: {:ok, atom()} | :error

Label written on CREATE for all nodes whose resource belongs to this domain.

neo4j_label!(dsl_or_extended)

@spec neo4j_label!(dsl_or_extended :: module() | map()) :: atom() | no_return()

Label written on CREATE for all nodes whose resource belongs to this domain.

neo4j_options(dsl_or_extended)

@spec neo4j_options(dsl_or_extended :: module() | map()) :: %{
  required(atom()) => any()
}

neo4j DSL options

Returns a map containing the and any configured or default values.