Introspection helpers for AshNeo4j.DataLayer
Summary
Functions
Optional list of node relationships, as tuples of {edge_label, edge_direction, destination_label}
Optional list of node relationships, as tuples of {edge_label, edge_direction, destination_label}
Optional node label
Optional node label
neo4j DSL options
Optional list of relationships, as tuples of {relationship_name, edge_label, edge_direction, destination_label}
Optional list of relationships, as tuples of {relationship_name, edge_label, edge_direction, destination_label}
Optional list of attributes not to be stored directly as node properties
Optional list of attributes not to be stored directly as node properties
Functions
@spec neo4j_guard(dsl_or_extended :: module() | map()) :: {:ok, [{atom(), atom(), atom()}]} | :error
Optional list of node relationships, as tuples of {edge_label, edge_direction, destination_label}
Optional list of node relationships, as tuples of {edge_label, edge_direction, destination_label}
Optional node label
Optional node label
neo4j DSL options
Returns a map containing the and any configured or default values.
@spec neo4j_relate(dsl_or_extended :: module() | map()) :: {:ok, [{atom(), atom(), atom(), atom()}]} | :error
Optional list of relationships, as tuples of {relationship_name, edge_label, edge_direction, destination_label}
@spec neo4j_relate!(dsl_or_extended :: module() | map()) :: [{atom(), atom(), atom(), atom()}] | no_return()
Optional list of relationships, as tuples of {relationship_name, edge_label, edge_direction, destination_label}
Optional list of attributes not to be stored directly as node properties
Optional list of attributes not to be stored directly as node properties