Introspection helpers for AshNeo4j.DataLayer.Domain
Summary
Functions
Label written on CREATE for all nodes whose resource belongs to this domain.
Label written on CREATE for all nodes whose resource belongs to this domain.
neo4j DSL options
Functions
Label written on CREATE for all nodes whose resource belongs to this domain.
Label written on CREATE for all nodes whose resource belongs to this domain.
neo4j DSL options
Returns a map containing the and any configured or default values.